==> haskell-mustache-2.4.3.1-31-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mustache.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mustache
version:              2.4.3.1
visibility:           public
id:                   mustache-2.4.3.1-JWX4cXP36MNEMgUUz8RVdC
key:                  mustache-2.4.3.1-JWX4cXP36MNEMgUUz8RVdC
license:              BSD-3-Clause
copyright:            (c) 2015 - 2022 Justus Adam
maintainer:           dev@justus.science
author:               Justus Adam
homepage:             https://github.com/JustusAdam/mustache#readme
synopsis:             A mustache template parser library.
description:
    Allows parsing and rendering template files with mustache markup. See the
    mustache <http://mustache.github.io/mustache.5.html language reference>.

    Implements the mustache spec version 1.1.3.

    /Note/: Versions including and beyond 0.4 are compatible with ghc 7.8 again.

category:             Development
abi:                  bcd43287c4d55ed0fae97c8a7b0cac09
exposed:              True
exposed-modules:
    Text.Mustache Text.Mustache.Compile Text.Mustache.Parser
    Text.Mustache.Render Text.Mustache.Types

hidden-modules:       Text.Mustache.Internal Text.Mustache.Internal.Types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/mustache-2.4.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mustache-2.4.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mustache-2.4.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mustache
hs-libraries:         HSmustache-2.4.3.1-JWX4cXP36MNEMgUUz8RVdC
depends:
    aeson-2.1.2.1-F8ZePgr6g4xL6kF4wsQx0x base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.7.1
    filepath-1.4.2.2 mtl-2.2.2 parsec-3.1.16.1
    scientific-0.3.8.0-IrrbGrT9lim10QS5UtlqtE template-haskell-2.19.0.0
    text-2.0.2 th-lift-0.8.6-HRVeiGNnDxNElRy2LmdExl
    unordered-containers-0.2.20-I3GOf8berWn8tol6ImoSEe
    vector-0.13.2.0-7bZcynEBhMGLMgNICkU4Wg

haddock-interfaces:   /usr/share/doc/haskell-mustache/html/mustache.haddock
haddock-html:         /usr/share/doc/haskell-mustache/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mustache-2.4.3.1-32-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mustache.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mustache
version:              2.4.3.1
visibility:           public
id:                   mustache-2.4.3.1-5rr99P8kRrOCzqCTjk6hXz
key:                  mustache-2.4.3.1-5rr99P8kRrOCzqCTjk6hXz
license:              BSD-3-Clause
copyright:            (c) 2015 - 2022 Justus Adam
maintainer:           dev@justus.science
author:               Justus Adam
homepage:             https://github.com/JustusAdam/mustache#readme
synopsis:             A mustache template parser library.
description:
    Allows parsing and rendering template files with mustache markup. See the
    mustache <http://mustache.github.io/mustache.5.html language reference>.

    Implements the mustache spec version 1.1.3.

    /Note/: Versions including and beyond 0.4 are compatible with ghc 7.8 again.

category:             Development
abi:                  6f42d233b87c24bc18e13aae000c6345
exposed:              True
exposed-modules:
    Text.Mustache Text.Mustache.Compile Text.Mustache.Parser
    Text.Mustache.Render Text.Mustache.Types

hidden-modules:       Text.Mustache.Internal Text.Mustache.Internal.Types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/mustache-2.4.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mustache-2.4.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mustache-2.4.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mustache
hs-libraries:         HSmustache-2.4.3.1-5rr99P8kRrOCzqCTjk6hXz
depends:
    aeson-2.1.2.1-IZ8jLcnEISD7S5Vyf2Tehm base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.7.1
    filepath-1.4.2.2 mtl-2.2.2 parsec-3.1.16.1
    scientific-0.3.8.0-JtTPeMck4RoCJw8PpYbrMQ template-haskell-2.19.0.0
    text-2.0.2 th-lift-0.8.6-HRVeiGNnDxNElRy2LmdExl
    unordered-containers-0.2.20-79maJZZuZDu8bRI1CHuoJG
    vector-0.13.2.0-9TreTxHfwqF7cSCfMWPj9u

haddock-interfaces:   /usr/share/doc/haskell-mustache/html/mustache.haddock
haddock-html:         /usr/share/doc/haskell-mustache/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
